@@ -1,7 +1,7 @@
 // -*- c++ -*-
 #ifndef _GLIBMM_VALUE_H
 #define _GLIBMM_VALUE_H
-/* $Id: value.h 190 2005-01-21 19:26:04Z murrayc $ */
+/* $Id: value.h,v 1.11 2006/05/14 12:12:41 murrayc Exp $ */
 
 /* Copyright 2002 The gtkmm Development Team
  *
@@ -69,9 +69,21 @@ public:
    *
    * init() is not implemented as constructor, to avoid the necessity
    * to implement a forward constructor in each derived class.
+   *
+   * @param type The type that the Value should hold.
    */
   void init(GType type);
 
+  /** Setup the GValue storing the type and value of the specified @a value.
+   * Note that init() should never be called twice.
+   *
+   * init() is not implemented as constructor, to avoid the necessity
+   * to implement a forward constructor in each derived class.
+   *
+   * @param value The existing GValue.
+   */
+  void init(const GValue* value);
+
   /** Reset contents to the default value of its type.
    */
   void reset();
